@@ -3,6 +3,7 @@ from authlib.oauth2.rfc7523.jwt_bearer import JWTBearerGrant
 
 BASE_AUD_URL = "/api/v1/gateway/services"
 
+
 class NeverminedJWTBearerGrant(JWTBearerGrant):
     def create_claims_options(self):
         """Create a claims_options to verify JWT payload claims.
@@ -19,10 +20,11 @@ class NeverminedJWTBearerGrant(JWTBearerGrant):
                 'essential': True,
                 'values': [
                     BASE_AUD_URL + '/access',
+                    BASE_AUD_URL + '/nft-access',
                     BASE_AUD_URL + '/compute',
                     BASE_AUD_URL + '/download',
                     BASE_AUD_URL + '/execute'
-               ],
+                ],
             },
             'exp': {'essential': True},
         }
@@ -71,13 +73,13 @@ def validate_execution_id(claims, value):
     return True
 
 
-def generate_access_grant_token(account, service_agreement_id, did):
-     # create jwt bearer grant
+def generate_access_grant_token(account, service_agreement_id, did, uri="/access"):
+    # create jwt bearer grant
     jwk = account_to_jwk(account)
     assertion = NeverminedJWTBearerGrant.sign(
         jwk,
         issuer=account.address,
-        audience=BASE_AUD_URL + "/access",
+        audience=BASE_AUD_URL + uri,
         subject=service_agreement_id,
         claims={
             "did": did
@@ -107,7 +109,7 @@ def generate_download_grant_token(account, did):
 
 
 def generate_execute_grant_token(account, service_agreement_id, workflow_did):
-     # create jwt bearer grant
+    # create jwt bearer grant
     jwk = account_to_jwk(account)
     assertion = NeverminedJWTBearerGrant.sign(
         jwk,
@@ -125,7 +127,7 @@ def generate_execute_grant_token(account, service_agreement_id, workflow_did):
 
 
 def generate_compute_grant_token(account, service_agreement_id, execution_id):
-     # create jwt bearer grant
+    # create jwt bearer grant
     jwk = account_to_jwk(account)
     assertion = NeverminedJWTBearerGrant.sign(
         jwk,
@@ -139,4 +141,4 @@ def generate_compute_grant_token(account, service_agreement_id, execution_id):
             "alg": "ES256K"
         })
 
-    return assertion
\ No newline at end of file
+    return assertion
