@@ -5,9 +5,9 @@ import rsa
 from Crypto import Random
 from Crypto.Cipher import AES
 from Crypto.Protocol.KDF import PBKDF2
-from ecies import encrypt, decrypt
+from ecies import decrypt, encrypt
 from eth_keys import keys
-from eth_utils import to_hex
+from eth_utils import to_bytes, to_hex
 from web3.auto import w3
 
 BLOCK_SIZE = 16
@@ -36,7 +36,7 @@ def get_ecdsa_public_key_from_file(keyfile_path, keyfile_password):
     return to_hex(pk.public_key._raw_key)  # hex string
 
 
-def ecdsa_encription_from_file(message, provider_key_file, provider_password):
+def ecdsa_encryption_from_file(message, provider_key_file, provider_password):
     public_key_hex = get_ecdsa_public_key_from_file(provider_key_file, provider_password)
     encrypted_message = encryption(public_key_hex, message.encode())
     hash = to_hex(encrypted_message)
@@ -45,23 +45,17 @@ def ecdsa_encription_from_file(message, provider_key_file, provider_password):
 
 def ecdsa_decryption(message, provider_key_file, provider_password):
     (public_key_hex, private_key_hex) = get_keys_from_file(provider_key_file, provider_password)
-    result = decryption(private_key_hex, message)
+    result = decryption(private_key_hex, to_bytes(hexstr=message))
     return result.decode()
 
 
-def rsa_encription_from_file(message, rsa_public_key_file):
+def rsa_encryption_from_file(message, rsa_public_key_file):
     pub_key = get_rsa_public_key_from_file(rsa_public_key_file)
-    encrypted_message = rsa_encryption(pub_key, message.encode())
-    hash = to_hex(encrypted_message)
+    encrypted_message, aes_encrypted_key = rsa_encryption(pub_key, message.encode())
+    hash = to_hex(encrypted_message) + '|' + to_hex(aes_encrypted_key)
     return hash, get_content_keyfile_from_path(rsa_public_key_file)
 
 
-def rsa_decryption(message, rsa_private_key_file):
-    priv_key = get_rsa_private_key_from_file(rsa_private_key_file)
-    result = rsa_decryption(priv_key, message.encode())
-    return result.decode()
-
-
 def get_content_keyfile_from_path(keyfile_path):
     with open(keyfile_path, mode='r') as keyfile:
         key_content = keyfile.read()
@@ -90,6 +84,16 @@ def rsa_encryption(public_key, data):
     return encrypted_data, encrypted_aes_key
 
 
+def rsa_decryption_aes(message, rsa_private_key_file):
+    if '|' in message:  # The message includes an encrypted AES key
+        tokens = message.split('|')
+        return rsa_decryption(get_rsa_private_key_from_file(rsa_private_key_file),
+                              to_bytes(hexstr=tokens[0]), to_bytes(hexstr=tokens[1]))
+    priv_key = get_rsa_private_key_from_file(rsa_private_key_file)
+    result = rsa.decrypt(to_bytes(hexstr=message), priv_key)
+    return result.decode()
+
+
 def rsa_decryption(private_key, encrypted_data, encrypted_aes_key):
     aes_key = rsa.decrypt(encrypted_aes_key, private_key)
     return aes_decryption(encrypted_data, aes_key)
@@ -125,4 +129,3 @@ def encryption(public_key_hex, data):
 
 def decryption(private_key_hex, encrypted_data):
     return decrypt(private_key_hex, encrypted_data)
-
